@@ -270,7 +270,7 @@ sub readRecord {
   $memo=''	unless defined($memo);
   $memo.=$m;
  }
- $memo=~s/( +|\00+)\z//	if $memo;
+ $memo=~s/( +|\00+)$//	if $memo;
  push @Data, $memo;
 
  return 1;
@@ -382,7 +382,8 @@ sub decrypt {
  my $res='';
  do{
   my($c1, $c2)=unpack('C2', $str);
-  defined($c2)	or return $res.$str;
+  defined($c1)	or return $res;
+  defined($c2)	or return $res.pack('C', $c1);
   $res.=pack('C2', $c1^$self->{Key}[0], $c2^$self->{Key}[1]);
   $str=unpack('x2 a*', $str);
  }while(1);
@@ -412,8 +413,7 @@ sub unpackBCD {
 
  my $sign=substr($bcd, 0, 1) eq '0' ? '' : '-';
  $bcd=substr($bcd, 1);
- $bcd=~s/\D/9/g	and
-    warn "Incorrect DECIMAL value!\n";
+ $bcd=~s/\D/9/g	and warn "Incorrect DECIMAL value!\n";
  
  my $sig=substr($bcd, 0, $decsig);
  $sig=~s/^0+//;
